@@ -23,7 +23,3 @@ def desktop() -> list[str]:
 def add(a: int, b: int) -> int:
     """Add two numbers"""
     return a + b
-
-
-if __name__ == "__main__":
-    mcp.run()
